.. Copyright (C) 2017 Fabio Bonelli <fb@fabiobonelli.it>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.root_account`` Ansible role can be used to manage the system root
account and generate SSH private keys for use on other hosts.
